@@ -94,13 +94,14 @@ class Collector:
 				if fnmatch.fnmatch(name,pattern):return _B
 		return _C
 class Runner:
+	case_list=[]
 	@classmethod
 	def run(cls):
 		if not Collector.exec_list:signal.criticalInfo('没有可以执行的测试用例');return 2
 		cls.caseId=0
 		for (name,meta) in Collector.exec_table.items():
 			if meta[_G]==_J and _E in meta:cls._insertTeardownToExecList(name)
-		signal.testStart();cls.execTest();signal.testEnd();from hytest.common import GSTORE;return GSTORE['---ret---']
+		signal.test_start();cls.execTest();signal.test_end(cls);from hytest.common import GSTORE;return GSTORE.get('---ret---',3)
 	@classmethod
 	def execTest(cls):
 		A='suite';suite_setup_failed_list=[]
@@ -147,7 +148,7 @@ class Runner:
 	def _exec_cases(cls,meta):
 		B='case_default';A='case';test_setup=meta.get(_N);test_teardown=meta.get(_O)
 		for case in meta[_A]:
-			case_className=type(case).__name__;cls.caseId+=1;signal.enter_case(cls.caseId,case.name,case_className);caseSetup=getattr(case,'setup',_F)
+			cls.case_list.append(case);case_className=type(case).__name__;cls.caseId+=1;signal.enter_case(cls.caseId,case.name,case_className);caseSetup=getattr(case,'setup',_F)
 			if caseSetup:
 				signal.setup(case.name,A)
 				try:caseSetup()
@@ -157,9 +158,9 @@ class Runner:
 				try:test_setup()
 				except Exception as e:signal.setup_fail(case.name,B,e,traceback.format_exc());continue
 			signal.case_steps(case.name)
-			try:case.teststeps();signal.case_pass(cls.caseId,case.name)
-			except AssertionError as e:signal.case_fail(cls.caseId,case.name,e,traceback.format_exc())
-			except Exception as e:signal.case_abort(cls.caseId,case.name,e,traceback.format_exc())
+			try:case.teststeps();case.execRet='pass';signal.case_result(case)
+			except AssertionError as e:case.execRet='fail';case.error=e;case.stacktrace=traceback.format_exc();signal.case_result(case)
+			except Exception as e:case.execRet='abort';case.error=e;case.stacktrace=traceback.format_exc();signal.case_result(case)
 			caseTeardown=getattr(case,'teardown',_F)
 			if caseTeardown:
 				signal.teardown(case.name,A)
